Links class abstract

Links is a multi-purpose class made to handle HTTP links with your app. Its used by DioClient to setup new instances

Constructors

Links()
const

Properties

devUrl → String
the server url for the development environment
no setter
hashCode → int
The hash code for this object.
no setterinherited
productionUrl → String
the server url for the production environment
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server → String
returns an url based on the value of the environment variable 'FLAVOR'. Possible values are 'production', 'dev' and 'staging'. Defaults to 'production'
no setter
stagingUrl → String
the server url for the staging/testing environment
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ Links
getter/setter pair